__author__ = "Oscar de Felice"
__email__ = "oscar.defelice@gmail.com"
__copyright__ = "(c) 2023 Oscar de Felice"

__license__ = "MIT"
__version__ = "1.0.4"
__title__ = 'GIT Message Hook'
__description__ = 'Force conventional git commit messages for git repositories, by leveraging git hooks.'
